# Generated by roxygen2: do not edit by hand

export(file_subs_ext)
export(format_copypaste)
export(format_traditional)
export(get_extensions)
export(markdown_block)
export(md_figure)
export(md_table)
export(mdtangle)
export(mdweave)
export(mdweave_to_html)
export(mdweave_to_pdf)
export(mdweave_to_tex)
export(output_eval)
export(output_figure)
export(output_raw)
export(output_shell)
export(output_str)
export(output_table)
export(raw_block)
export(run_and_capture)
importFrom(rjson,fromJSON)
